var VueDropdownMultiselect = (function (exports, vue) {
  'use strict';

  var script = {
    name: "VueDropdownMultiselect",
    props: {
      items: {
        type: Array,
        default: function () { return []; }
      },
      multiSelect: {
        type: Boolean,
        default: false
      },
      searchable: {
        type: Boolean,
        default: false
      },
      isChecked: {
        type: Boolean,
        default: false
      },
      placeholderBtn: {
        type: String,
        default: "Select an Option"
      },
      itemClass: {
        type: String,
        default: null
      },
      searchPlaceholder: {
        type: String,
        default: "Search"
      },
      btnClass: {
        type: String,
        default: ""
      },
      containerClass: {
        type: String,
        default: ""
      },
      searchClass: {
        type: String,
        default: ""
      }
    },
    data: function data() {
      return {
        stateToSearch: "",
        popupLocationFilter: false,
        selectedToExport: [],
        elements: []
      };
    },
    computed: {
      placeholderBtnText: function placeholderBtnText() {
        if (this.placeholderBtn) {
          return this.placeholderBtn;
        }
        return "Select an Option";
      },
      searchPlaceholderText: function searchPlaceholderText() {
        if (this.searchPlaceholder) {
          return this.searchPlaceholder;
        }
        return "Search";
      },
      hasBtnText: function hasBtnText() {
        return !!this.$slots.btnText;
      },
      itemClassName: function itemClassName() {
        if (this.itemClass) {
          return this.itemClass;
        }
        return "selected";
      },
      btnClassName: function btnClassName() {
        if (this.btnClass) {
          return this.btnClass;
        }
        return "vue-main-btn";
      },
      containerClassName: function containerClassName() {
        if (this.containerClass) {
          return this.containerClass;
        }
        return "vue-main-container";
      }
    },
    created: function created() {
      this.formatItems();
    },
    methods: {
      onClose: function onClose() {
        this.saveLocations();
        this.popupLocationFilter = false;
      },
      clearFilters: function clearFilters() {
        this.elements.forEach(function (item) {
          item.checked = false;
          item.matches = true;
        });

        this.stateToSearch = "";
      },
      handleTyping: function handleTyping() {
        var this$1$1 = this;

        this.elements.forEach(function (item) {
          var matchWithStateName = item.name
            .toLowerCase()
            .includes(this$1$1.stateToSearch.toLowerCase());

          item.matches = matchWithStateName ? true : false;
        });
      },
      formatItems: function formatItems() {
        var this$1$1 = this;

        this.elements = this.items;
        this.elements.forEach(function (item) {
          item.matches = true;
          if (item.checked) {
            this$1$1.selectedToExport.push(item.value);
          } else {
            item.checked = false;
          }
          if (!item.disabled) {
            item.disabled = false;
          }
        });
        this.$emit("input", this.selectedToExport);
      },
      handleSelection: function handleSelection(item) {
        if (item.checked) {
          item.checked = false;
          if (Array.isArray(this.selectedToExport)) {
            this.selectedToExport = this.selectedToExport.filter(
              function (e) { return e != item.value; }
            );
          }
        } else {
          if (!item.disabled) {
            if (this.multiSelect) {
              this.selectedToExport.push(item.value);
            } else {
              this.selectedToExport = [];
              this.selectedToExport.push(item.value);
              this.elements.map(function (i) {
                i.checked = false;
              });
            }
            item.checked = true;
          }
        }
        this.$emit("input", this.selectedToExport);
        this.$forceUpdate();
      },
      saveLocations: function saveLocations() {
        this.popupLocationFilter = !this.popupLocationFilter;
        if (!this.popupLocationFilter) {
          this.$emit("hidden");
        }
      },
      cleanSelected: function cleanSelected(name) {
        this.selectedToExport = this.selectedToExport.filter(function (e) { return e != name; });
        name = name.split(" (")[0];
      }
    },
    directives: {
      clickoutside: {
        bind: function(el, binding, node) {
          el.clickOutsideEvent = function(event) {
            if (!(el == event.target || el.contains(event.target))) {
              node.context[binding.expression](event);
            }
          };
          document.body.addEventListener("click", el.clickOutsideEvent);
        },
        unbind: function(el) {
          document.body.removeEventListener("click", el.clickOutsideEvent);
        },
        stopProp: function stopProp(event) {
          event.stopPropagation();
        }
      }
    }
  };

  var _hoisted_1 = { class: "vue-dropdown" };
  var _hoisted_2 = {
    key: 0,
    class: "search-container"
  };
  var _hoisted_3 = { class: "" };
  var _hoisted_4 = { key: 1 };
  var _hoisted_5 = /*#__PURE__*/vue.createVNode("div", { class: "" }, null, -1 /* HOISTED */);

  function render(_ctx, _cache, $props, $setup, $data, $options) {
    var _directive_clickoutside = vue.resolveDirective("clickoutside");

    return vue.withDirectives((vue.openBlock(), vue.createBlock("div", _hoisted_1, [
      vue.createVNode("button", {
        class: $options.btnClassName,
        onClick: _cache[1] || (_cache[1] = function () {
          var args = [], len = arguments.length;
          while ( len-- ) args[ len ] = arguments[ len ];

          return ($options.saveLocations && $options.saveLocations.apply($options, args));
    })
      }, [
        ($options.hasBtnText)
          ? vue.renderSlot(_ctx.$slots, "btnText", { key: 0 })
          : (vue.openBlock(), vue.createBlock(vue.Fragment, { key: 1 }, [
              vue.createTextVNode(vue.toDisplayString($options.placeholderBtnText), 1 /* TEXT */)
            ], 2112 /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */))
      ], 2 /* CLASS */),
      ($data.popupLocationFilter)
        ? (vue.openBlock(), vue.createBlock("div", {
            key: 0,
            class: ("bg " + ($options.containerClassName))
          }, [
            ($props.searchable)
              ? (vue.openBlock(), vue.createBlock("div", _hoisted_2, [
                  vue.withDirectives(vue.createVNode("input", {
                    "onUpdate:modelValue": _cache[2] || (_cache[2] = function ($event) { return ($data.stateToSearch = $event); }),
                    class: ("vue-search " + ($props.searchClass)),
                    placeholder: $options.searchPlaceholderText,
                    onInput: _cache[3] || (_cache[3] = function ($event) { return ($options.handleTyping()); })
                  }, null, 42 /* CLASS, PROPS, HYDRATE_EVENTS */, ["placeholder"]), [
                    [vue.vModelText, $data.stateToSearch]
                  ])
                ]))
              : vue.createCommentVNode("v-if", true),
            vue.createVNode("div", _hoisted_3, [
              (vue.openBlock(true), vue.createBlock(vue.Fragment, null, vue.renderList($data.elements, function (item, index) {
                return (vue.openBlock(), vue.createBlock("div", {
                  key: index,
                  class: ["pointer", { hide: !item.matches }]
                }, [
                  ($props.isChecked)
                    ? (vue.openBlock(), vue.createBlock("p", {
                        key: 0,
                        class: 
                ("item-flex pointer " + (item.checked ? $options.itemClassName : '') + " " + (item.disabled ? 'disabled' : ''))
              
                      }, [
                        vue.createVNode("input", {
                          class: "pointer",
                          type: "checkbox",
                          id: item.name,
                          name: item.name,
                          value: item.name,
                          checked: item.checked && !item.disabled,
                          disabled: item.disabled,
                          onClick: function ($event) { return ($options.handleSelection(item)); }
                        }, null, 8 /* PROPS */, ["id", "name", "value", "checked", "disabled", "onClick"]),
                        vue.createVNode("label", {
                          for: item.name,
                          class: "pointer"
                        }, vue.toDisplayString(item.name), 9 /* TEXT, PROPS */, ["for"])
                      ], 2 /* CLASS */))
                    : (vue.openBlock(), vue.createBlock("div", _hoisted_4, [
                        vue.createVNode("p", {
                          onClick: function ($event) { return ($options.handleSelection(item)); },
                          for: item.name,
                          class: 
                  ("item-flex pointer " + (item.checked ? $options.itemClassName : '') + " " + (item.disabled ? 'disabled' : ''))
                
                        }, vue.toDisplayString(item.name), 11 /* TEXT, CLASS, PROPS */, ["onClick", "for"])
                      ])),
                  _hoisted_5
                ], 2 /* CLASS */))
              }), 128 /* KEYED_FRAGMENT */))
            ])
          ], 2 /* CLASS */))
        : vue.createCommentVNode("v-if", true)
    ], 512 /* NEED_PATCH */)), [
      [_directive_clickoutside, $options.onClose]
    ])
  }

  script.render = render;
  script.__file = "src/VueDropdownMultiselect.vue";

  // Import vue component

  // Declare install function executed by Vue.use()
  function install(Vue) {
    if (install.installed) { return; }
    install.installed = true;
    Vue.component("VueDropdownMultiselect", script);
  }

  // Create module definition for Vue.use()
  var plugin = {
    install: install
  };

  // Auto-install when vue is found (eg. in browser via <script> tag)
  var GlobalVue = null;
  if (typeof window !== "undefined") {
    GlobalVue = window.Vue;
  } else if (typeof global !== "undefined") {
    GlobalVue = global.Vue;
  }
  if (GlobalVue) {
    GlobalVue.use(plugin);
  }

  script.install = install;

  exports.default = script;
  exports.install = install;

  Object.defineProperty(exports, '__esModule', { value: true });

  return exports;

}({}, vue));
